@@ -9,6 +9,9 @@
 ---
 <!--END STABILITY BANNER-->
 
+If you're migrating from the old `assert` library, the migration guide can be found in
+[our GitHub repository](https://github.com/aws/aws-cdk/blob/master/packages/@aws-cdk/assertions/MIGRATING.md).
+
 Functions for writing test asserting against CDK applications, with focus on CloudFormation templates.
 
 The `Template` class includes a set of methods for writing assertions against CloudFormation templates. Use one of the `Template.fromXxx()` static methods to create an instance of this class.
@@ -139,7 +142,7 @@ expect(result.Foo).to_equal({"Value": "Fred", "Description": "FooFred"})
 expect(result.Bar).to_equal({"Value": "Fred", "Description": "BarFred"})
 ```
 
-The APIs `hasMapping()` and `findMappings()` provide similar functionalities.
+The APIs `hasMapping()`, `findMappings()`, `hasCondition()`, and `hasCondtions()` provide similar functionalities.
 
 ## Special Matchers
 
@@ -251,7 +254,7 @@ This matcher can be combined with any of the other matchers.
 # The following will NOT throw an assertion error
 template.has_resource_properties("Foo::Bar", {
     "Fred": {
-        "Wobble": [Match.any_value(), "Flip"]
+        "Wobble": [Match.any_value(), Match.any_value()]
     }
 })
 
@@ -299,6 +302,35 @@ target array. Out of order will be recorded as a match failure.
 Alternatively, the `Match.arrayEquals()` API can be used to assert that the target is
 exactly equal to the pattern array.
 
+### String Matchers
+
+The `Match.stringLikeRegexp()` API can be used to assert that the target matches the
+provided regular expression.
+
+```python
+# Given a template -
+# {
+#   "Resources": {
+#     "MyBar": {
+#       "Type": "Foo::Bar",
+#       "Properties": {
+#         "Template": "const includeHeaders = true;"
+#       }
+#     }
+#   }
+# }
+
+# The following will NOT throw an assertion error
+template.has_resource_properties("Foo::Bar", {
+    "Template": Match.string_like_regexp("includeHeaders = (true|false)")
+})
+
+# The following will throw an assertion error
+template.has_resource_properties("Foo::Bar", {
+    "Template": Match.string_like_regexp("includeHeaders = null")
+})
+```
+
 ### Not Matcher
 
 The not matcher inverts the search pattern and matches all patterns in the path that does
@@ -368,7 +400,7 @@ template.has_resource_properties("Foo::Bar", {
 
 ## Capturing Values
 
-This matcher APIs documented above allow capturing values in the matching entry
+The matcher APIs documented above allow capturing values in the matching entry
 (Resource, Output, Mapping, etc.). The following code captures a string from a
 matching resource.
 
@@ -460,6 +492,66 @@ fred_capture.as_string() # returns "Flob"
 fred_capture.next() # returns true
 fred_capture.as_string()
 ```
+
+## Asserting Annotations
+
+In addition to template matching, we provide an API for annotation matching.
+[Annotations](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.Annotations.html)
+can be added via the [Aspects](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.Aspects.html)
+API. You can learn more about Aspects [here](https://docs.aws.amazon.com/cdk/v2/guide/aspects.html).
+
+Say you have a `MyAspect` and a `MyStack` that uses `MyAspect`:
+
+```python
+import aws_cdk.core as cdk
+from constructs import Construct, IConstruct
+
+class MyAspect(cdk.IAspect):
+    def visit(self, node):
+        if node instanceof cdk.CfnResource && node.cfn_resource_type == "Foo::Bar":
+            self.error(node, "we do not want a Foo::Bar resource")
+
+    def error(self, node, message):
+        cdk.Annotations.of(node).add_error(message)
+
+class MyStack(cdk.Stack):
+    def __init__(self, scope, id):
+        super().__init__(scope, id)
+
+        stack = cdk.Stack()
+        cdk.CfnResource(stack, "Foo",
+            type="Foo::Bar",
+            properties={
+                "Fred": "Thud"
+            }
+        )
+        cdk.Aspects.of(stack).add(MyAspect())
+```
+
+We can then assert that the stack contains the expected Error:
+
+```python
+# import { Annotations } from '@aws-cdk/assertions';
+
+Annotations.from_stack(stack).has_error("/Default/Foo", "we do not want a Foo::Bar resource")
+```
+
+Here are the available APIs for `Annotations`:
+
+* `hasError()` and `findError()`
+* `hasWarning()` and `findWarning()`
+* `hasInfo()` and `findInfo()`
+
+The corresponding `findXxx()` API is complementary to the `hasXxx()` API, except instead
+of asserting its presence, it returns the set of matching messages.
+
+In addition, this suite of APIs is compatable with `Matchers` for more fine-grained control.
+For example, the following assertion works as well:
+
+```python
+Annotations.from_stack(stack).has_error("/Default/Foo",
+    Match.string_like_regexp(".*Foo::Bar.*"))
+```
 '''
 import abc
 import builtins
@@ -474,6 +566,102 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.core
+import aws_cdk.cx_api
+
+
+class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annotations"):
+    '''Suite of assertions that can be run on a CDK Stack.
+
+    Focused on asserting annotations.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.assertions as assertions
+        import aws_cdk.core as cdk
+        
+        # stack: cdk.Stack
+        
+        annotations = assertions.Annotations.from_stack(stack)
+    '''
+
+    @jsii.member(jsii_name="fromStack") # type: ignore[misc]
+    @builtins.classmethod
+    def from_stack(cls, stack: aws_cdk.core.Stack) -> "Annotations":
+        '''Base your assertions on the messages returned by a synthesized CDK ``Stack``.
+
+        :param stack: the CDK Stack to run assertions on.
+        '''
+        return typing.cast("Annotations", jsii.sinvoke(cls, "fromStack", [stack]))
+
+    @jsii.member(jsii_name="findError")
+    def find_error(
+        self,
+        construct_path: builtins.str,
+        message: typing.Any,
+    ) -> typing.List[aws_cdk.cx_api.SynthesisMessage]:
+        '''Get the set of matching errors of a given construct path and message.
+
+        :param construct_path: the construct path to the error. Provide ``'*'`` to match all errors in the template.
+        :param message: the error message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findError", [construct_path, message]))
+
+    @jsii.member(jsii_name="findInfo")
+    def find_info(
+        self,
+        construct_path: builtins.str,
+        message: typing.Any,
+    ) -> typing.List[aws_cdk.cx_api.SynthesisMessage]:
+        '''Get the set of matching infos of a given construct path and message.
+
+        :param construct_path: the construct path to the info. Provide ``'*'`` to match all infos in the template.
+        :param message: the info message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findInfo", [construct_path, message]))
+
+    @jsii.member(jsii_name="findWarning")
+    def find_warning(
+        self,
+        construct_path: builtins.str,
+        message: typing.Any,
+    ) -> typing.List[aws_cdk.cx_api.SynthesisMessage]:
+        '''Get the set of matching warning of a given construct path and message.
+
+        :param construct_path: the construct path to the warning. Provide ``'*'`` to match all warnings in the template.
+        :param message: the warning message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findWarning", [construct_path, message]))
+
+    @jsii.member(jsii_name="hasError")
+    def has_error(self, construct_path: builtins.str, message: typing.Any) -> None:
+        '''Assert that an error with the given message exists in the synthesized CDK ``Stack``.
+
+        :param construct_path: the construct path to the error. Provide ``'*'`` to match all errors in the template.
+        :param message: the error message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasError", [construct_path, message]))
+
+    @jsii.member(jsii_name="hasInfo")
+    def has_info(self, construct_path: builtins.str, message: typing.Any) -> None:
+        '''Assert that an info with the given message exists in the synthesized CDK ``Stack``.
+
+        :param construct_path: the construct path to the info. Provide ``'*'`` to match all info in the template.
+        :param message: the info message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasInfo", [construct_path, message]))
+
+    @jsii.member(jsii_name="hasWarning")
+    def has_warning(self, construct_path: builtins.str, message: typing.Any) -> None:
+        '''Assert that an warning with the given message exists in the synthesized CDK ``Stack``.
+
+        :param construct_path: the construct path to the warning. Provide ``'*'`` to match all warnings in the template.
+        :param message: the warning message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasWarning", [construct_path, message]))
 
 
 class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Match"):
@@ -571,6 +759,15 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         '''
         return typing.cast("Matcher", jsii.sinvoke(cls, "serializedJson", [pattern]))
 
+    @jsii.member(jsii_name="stringLikeRegexp") # type: ignore[misc]
+    @builtins.classmethod
+    def string_like_regexp(cls, pattern: builtins.str) -> "Matcher":
+        '''Matches targets according to a regular expression.
+
+        :param pattern: -
+        '''
+        return typing.cast("Matcher", jsii.sinvoke(cls, "stringLikeRegexp", [pattern]))
+
 
 class _MatchProxy(Match):
     pass
@@ -599,8 +796,8 @@ class MatchCapture:
             # The values are placeholders you should change.
             import aws_cdk.assertions as assertions
             
-            # capture is of type Capture
-            # value is of type object
+            # capture: assertions.Capture
+            # value: Any
             
             match_capture = assertions.MatchCapture(
                 capture=capture,
@@ -665,7 +862,7 @@ class MatchFailure:
             # The values are placeholders you should change.
             import aws_cdk.assertions as assertions
             
-            # matcher is of type Matcher
+            # matcher: assertions.Matcher
             
             match_failure = assertions.MatchFailure(
                 matcher=matcher,
@@ -728,7 +925,7 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         # The values are placeholders you should change.
         import aws_cdk.assertions as assertions
         
-        # target is of type object
+        # target: Any
         
         match_result = assertions.MatchResult(target)
     '''
@@ -846,7 +1043,7 @@ class Matcher(
         #     "MyBar": {
         #       "Type": "Foo::Bar",
         #       "Properties": {
-        #         "Baz": "{ \"Fred\": [\"Waldo\", \"Willow\"] }"
+        #         "Fred": ["Flob", "Cat"]
         #       }
         #     }
         #   }
@@ -854,17 +1051,13 @@ class Matcher(
         
         # The following will NOT throw an assertion error
         template.has_resource_properties("Foo::Bar", {
-            "Baz": Match.serialized_json({
-                "Fred": Match.array_with(["Waldo"])
-            })
+            "Fred": Match.array_with(["Flob"])
         })
         
         # The following will throw an assertion error
-        template.has_resource_properties("Foo::Bar", {
-            "Baz": Match.serialized_json({
-                "Fred": ["Waldo", "Johnny"]
-            })
-        })
+        template.has_resource_properties("Foo::Bar", Match.object_like({
+            "Fred": Match.array_with(["Wobble"])
+        }))
     '''
 
     def __init__(self) -> None:
@@ -979,6 +1172,19 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         '''
         return typing.cast("Template", jsii.sinvoke(cls, "fromString", [template]))
 
+    @jsii.member(jsii_name="findConditions")
+    def find_conditions(
+        self,
+        logical_id: builtins.str,
+        props: typing.Any = None,
+    ) -> typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]]:
+        '''Get the set of matching Conditions that match the given properties in the CloudFormation template.
+
+        :param logical_id: the name of the condition. Provide ``'*'`` to match all conditions in the template.
+        :param props: by default, matches all Conditions in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findConditions", [logical_id, props]))
+
     @jsii.member(jsii_name="findMappings")
     def find_mappings(
         self,
@@ -1005,6 +1211,19 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findOutputs", [logical_id, props]))
 
+    @jsii.member(jsii_name="findParameters")
+    def find_parameters(
+        self,
+        logical_id: builtins.str,
+        props: typing.Any = None,
+    ) -> typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]]:
+        '''Get the set of matching Parameters that match the given properties in the CloudFormation template.
+
+        :param logical_id: the name of the parameter. Provide ``'*'`` to match all parameters in the template.
+        :param props: by default, matches all Parameters in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findParameters", [logical_id, props]))
+
     @jsii.member(jsii_name="findResources")
     def find_resources(
         self,
@@ -1018,6 +1237,18 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findResources", [type, props]))
 
+    @jsii.member(jsii_name="hasCondition")
+    def has_condition(self, logical_id: builtins.str, props: typing.Any) -> None:
+        '''Assert that a Condition with the given properties exists in the CloudFormation template.
+
+        By default, performs partial matching on the resource, via the ``Match.objectLike()``.
+        To configure different behavour, use other matchers in the ``Match`` class.
+
+        :param logical_id: the name of the mapping. Provide ``'*'`` to match all conditions in the template.
+        :param props: the output as should be expected in the template.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasCondition", [logical_id, props]))
+
     @jsii.member(jsii_name="hasMapping")
     def has_mapping(self, logical_id: builtins.str, props: typing.Any) -> None:
         '''Assert that a Mapping with the given properties exists in the CloudFormation template.
@@ -1042,6 +1273,18 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         '''
         return typing.cast(None, jsii.invoke(self, "hasOutput", [logical_id, props]))
 
+    @jsii.member(jsii_name="hasParameter")
+    def has_parameter(self, logical_id: builtins.str, props: typing.Any) -> None:
+        '''Assert that a Parameter with the given properties exists in the CloudFormation template.
+
+        By default, performs partial matching on the parameter, via the ``Match.objectLike()``.
+        To configure different behavior, use other matchers in the ``Match`` class.
+
+        :param logical_id: the name of the parameter. Provide ``'*'`` to match all parameters in the template.
+        :param props: the parameter as should be expected in the template.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasParameter", [logical_id, props]))
+
     @jsii.member(jsii_name="hasResource")
     def has_resource(self, type: builtins.str, props: typing.Any) -> None:
         '''Assert that a resource of the given type and given definition exists in the CloudFormation template.
@@ -1208,6 +1451,7 @@ class Capture(
 
 
 __all__ = [
+    "Annotations",
     "Capture",
     "Match",
     "MatchCapture",
